@@ -9,6 +9,12 @@ class BaseClient(metaclass=ABCMeta):
     ) -> None:
         raise NotImplementedError
 
+    @abstractmethod
+    def set_gauge_value(
+        self, name: str, labels: Optional[Dict[str, Any]] = None, value: float = 0.0
+    ) -> None:
+        raise NotImplementedError
+
     @abstractmethod
     def register_metric(
         self,
